import { BaseClient, ClientConfig } from "@commerce-apps/core";
import { WafGroupEnvelope, ZonesEnvelope, FirewallRuleEnvelope, FirewallRulesEnvelope, WafGroupsEnvelope, WafRulesEnvelope, WafRuleEnvelope } from "./CdnApi.types";
export { ErrorResponse, Offset, Limit, SiteId, SearchRequest, PaginatedSearchResult, SimpleSearchResult, FirewallRule, CollectionResponseEnvelope, WafGroupEnvelope, Zone, ZonesEnvelope, ItemResponseEnvelope, ZoneEnvelope, FirewallRuleEnvelope, FirewallRulesEnvelope, WafGroupsEnvelope, WafRulesEnvelope, WafGroup, WafRuleEnvelope, WafRule, } from "./CdnApi.types";
/**
* Instantiate a Client object with desired ClientConfig to perform operations
* available in this API client.
*
* Note: When performing operations that require ShopperJWT authentication, an
* Authorization header containing a JWT can be added to the headers field of the
* ClientConfig object. The Client will use that Authorization header for all the
* operations it is used to perform.
*/
export declare class Client extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Retrieves zone information.
    */
    getZoneInfo(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            offset?: any;
            limit?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | ZonesEnvelope>;
    /**
    * Retrieves all WAF groups accessible to the caller.
    */
    getWafGroups(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            zoneId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | WafGroupsEnvelope>;
    /**
    * Update action or mode of a specific WAF group.
    */
    updateWafGroupById(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            zoneId: any;
            groupId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | WafGroupEnvelope>;
    /**
    * Retrieve WAF rules under the waf group specified by the caller.
    */
    getWafRules(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            zoneId: any;
            groupId?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | WafRulesEnvelope>;
    /**
    * Retrieve details of a specific WAF rule.
    */
    getWafRule(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            zoneId: any;
            ruleId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | WafRuleEnvelope>;
    /**
    * Update action of a specific WAF rule.
    */
    updateWafRuleById(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            zoneId: any;
            ruleId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | WafRuleEnvelope>;
    /**
    * Retrieves existing firewall rules.
    */
    getFirewallRules(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            zoneId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | FirewallRulesEnvelope>;
    /**
    * Creates a firewall rule.
    */
    createFirewallRule(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            zoneId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | FirewallRuleEnvelope>;
    /**
    * Retrieve a specific firewall rule.
    */
    getFirewallRuleById(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            zoneId: any;
            firewallRuleId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | FirewallRuleEnvelope>;
    /**
    * Update a specific firewall rule.
    */
    updateFirewallRuleById(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            zoneId: any;
            firewallRuleId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | FirewallRuleEnvelope>;
    /**
    * Delete a specific firewall rule.
    */
    deleteFirewallRule(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            zoneId: any;
            firewallRuleId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=CdnApi.d.ts.map