import { BaseClient, ClientConfig } from "@commerce-apps/core";
export { PaymentTransactionUpdateRequest, PaymentInstrumentUpdateRequest, OrderPaymentStatusUpdateRequest, OrderConfirmationStatusUpdateRequest, ShippingAddressUpdateRequest, OrderExternalStatusUpdateRequest, OrderShippingStatusUpdateRequest, OrderUpdateRequest, OrderExportStatusUpdateRequest, OrderStatusUpdateRequest, Offset, Limit, SiteId, SearchRequest, PaginatedSearchResult, SimpleSearchResult, Error, } from "./Orders.types";
/**
* Instantiate a Client object with desired ClientConfig to perform operations
* available in this API client.
*
* Note: When performing operations that require ShopperJWT authentication, an
* Authorization header containing a JWT can be added to the headers field of the
* ClientConfig object. The Client will use that Authorization header for all the
* operations it is used to perform.
*/
export declare class Client extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Updates the order.
    */
    patchSitesByIdOrdersById(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            orderNo: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
    /**
    * Updates the order confirmation status.
    */
    putSitesByIdOrdersByIdConfirmationStatus(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            orderNo: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
    /**
    * Updates the order export status. Setting the status to EXPORTED will also trigger the finalization of on-order inventory transactions for this order, meaning that all inventory transactions with type on-order will be moved into final inventory transactions. This is only relevant when on-order inventory is turned on for the inventory list ordered products are in.
    */
    putSitesByIdOrdersByIdExportStatus(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            orderNo: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
    /**
    * Updates the order external status.
    */
    putSitesByIdOrdersByIdExternalStatus(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            orderNo: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
    /**
    * Updates the order payment status.
    */
    putSitesByIdOrdersByIdPaymentStatus(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            orderNo: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
    /**
    * Updates the order shipping status.
    */
    putSitesByIdOrdersByIdShippingStatus(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            orderNo: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
    /**
    * Updates the order status. Orders which are in status NEW, OPEN, COMPLETED or CANCELLED can not be set to status CREATED or FAILED.
    */
    putSitesByIdOrdersByIdStatus(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            orderNo: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
    /**
    * Updates the payment instrument of an order.
    */
    patchSitesByIdOrdersByIdPaymentInstrumentsById(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            orderNo: any;
            paymentInstrumentId: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
    /**
    * Updates the transaction of an order payment instrument.
    */
    patchSitesByIdOrdersByIdPaymentInstrumentsByIdTransaction(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            orderNo: any;
            paymentInstrumentId: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
    /**
    * Updates (create or replace) the order shipment address.
    */
    putSitesByIdOrdersByIdShipmentsByIdShippingAddress(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            orderNo: any;
            shipmentId: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=Orders.d.ts.map