/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@commerce-apps/core");
exports.ClientConfig = core_1.ClientConfig;
const lodash_1 = tslib_1.__importDefault(require("lodash"));
/**
 * Instantiate a Client object with desired ClientConfig to perform operations
 * available in this API client.
 *
 * Note: When performing operations that require ShopperJWT authentication, an
 * Authorization header containing a JWT can be added to the headers field of the
 * ClientConfig object. The Client will use that Authorization header for all the
 * operations it is used to perform.
 */
class Client extends core_1.BaseClient {
  constructor(config) {
    super(config);
    if (!!!config.baseUri) {
      this.clientConfig.baseUri =
        "https://anypoint.mulesoft.com/mocking/api/v1/links/2a968e56-a214-422b-a6e2-61ed41faad5f/checkout/orders/{version}";
    }
  }
  /**
   * Updates the order.
   */
  patchSitesByIdOrdersById(options) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      orderNo: parameters["orderNo"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    queryParameters["siteId"] !== undefined
      ? queryParameters["siteId"]
      : this.clientConfig.parameters["siteId"];
    // @ts-ignore
    return core_1.StaticClient.patch({
      client: this,
      rawResponse: (options || {}).rawResponse,
      path: "/organizations/{organizationId}/orders/{orderNo}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Updates the order confirmation status.
   */
  putSitesByIdOrdersByIdConfirmationStatus(options) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      orderNo: parameters["orderNo"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    queryParameters["siteId"] !== undefined
      ? queryParameters["siteId"]
      : this.clientConfig.parameters["siteId"];
    // @ts-ignore
    return core_1.StaticClient.put({
      client: this,
      rawResponse: (options || {}).rawResponse,
      path:
        "/organizations/{organizationId}/orders/{orderNo}/confirmation-status",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Updates the order export status. Setting the status to EXPORTED will also trigger the finalization of on-order inventory transactions for this order, meaning that all inventory transactions with type on-order will be moved into final inventory transactions. This is only relevant when on-order inventory is turned on for the inventory list ordered products are in.
   */
  putSitesByIdOrdersByIdExportStatus(options) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      orderNo: parameters["orderNo"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    queryParameters["siteId"] !== undefined
      ? queryParameters["siteId"]
      : this.clientConfig.parameters["siteId"];
    // @ts-ignore
    return core_1.StaticClient.put({
      client: this,
      rawResponse: (options || {}).rawResponse,
      path: "/organizations/{organizationId}/orders/{orderNo}/export-status",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Updates the order external status.
   */
  putSitesByIdOrdersByIdExternalStatus(options) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      orderNo: parameters["orderNo"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    queryParameters["siteId"] !== undefined
      ? queryParameters["siteId"]
      : this.clientConfig.parameters["siteId"];
    // @ts-ignore
    return core_1.StaticClient.put({
      client: this,
      rawResponse: (options || {}).rawResponse,
      path: "/organizations/{organizationId}/orders/{orderNo}/external-status",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Updates the order payment status.
   */
  putSitesByIdOrdersByIdPaymentStatus(options) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      orderNo: parameters["orderNo"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    queryParameters["siteId"] !== undefined
      ? queryParameters["siteId"]
      : this.clientConfig.parameters["siteId"];
    // @ts-ignore
    return core_1.StaticClient.put({
      client: this,
      rawResponse: (options || {}).rawResponse,
      path: "/organizations/{organizationId}/orders/{orderNo}/payment-status",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Updates the order shipping status.
   */
  putSitesByIdOrdersByIdShippingStatus(options) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      orderNo: parameters["orderNo"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    queryParameters["siteId"] !== undefined
      ? queryParameters["siteId"]
      : this.clientConfig.parameters["siteId"];
    // @ts-ignore
    return core_1.StaticClient.put({
      client: this,
      rawResponse: (options || {}).rawResponse,
      path: "/organizations/{organizationId}/orders/{orderNo}/shipping-status",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Updates the order status. Orders which are in status NEW, OPEN, COMPLETED or CANCELLED can not be set to status CREATED or FAILED.
   */
  putSitesByIdOrdersByIdStatus(options) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      orderNo: parameters["orderNo"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    queryParameters["siteId"] !== undefined
      ? queryParameters["siteId"]
      : this.clientConfig.parameters["siteId"];
    // @ts-ignore
    return core_1.StaticClient.put({
      client: this,
      rawResponse: (options || {}).rawResponse,
      path: "/organizations/{organizationId}/orders/{orderNo}/status",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Updates the payment instrument of an order.
   */
  patchSitesByIdOrdersByIdPaymentInstrumentsById(options) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      orderNo: parameters["orderNo"],
      paymentInstrumentId: parameters["paymentInstrumentId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    queryParameters["siteId"] !== undefined
      ? queryParameters["siteId"]
      : this.clientConfig.parameters["siteId"];
    // @ts-ignore
    return core_1.StaticClient.patch({
      client: this,
      rawResponse: (options || {}).rawResponse,
      path:
        "/organizations/{organizationId}/orders/{orderNo}/payment-instruments/{paymentInstrumentId}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Updates the transaction of an order payment instrument.
   */
  patchSitesByIdOrdersByIdPaymentInstrumentsByIdTransaction(options) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      orderNo: parameters["orderNo"],
      paymentInstrumentId: parameters["paymentInstrumentId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    queryParameters["siteId"] !== undefined
      ? queryParameters["siteId"]
      : this.clientConfig.parameters["siteId"];
    // @ts-ignore
    return core_1.StaticClient.patch({
      client: this,
      rawResponse: (options || {}).rawResponse,
      path:
        "/organizations/{organizationId}/orders/{orderNo}/payment-instruments/{paymentInstrumentId}/transaction",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Updates (create or replace) the order shipment address.
   */
  putSitesByIdOrdersByIdShipmentsByIdShippingAddress(options) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      orderNo: parameters["orderNo"],
      shipmentId: parameters["shipmentId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    queryParameters["siteId"] !== undefined
      ? queryParameters["siteId"]
      : this.clientConfig.parameters["siteId"];
    // @ts-ignore
    return core_1.StaticClient.put({
      client: this,
      rawResponse: (options || {}).rawResponse,
      path:
        "/organizations/{organizationId}/orders/{orderNo}/shipments/{shipmentId}/shipping-address",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
}
exports.Client = Client;
exports.default = Client;
//# sourceMappingURL=Orders.js.map
