/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@commerce-apps/core");
exports.ClientConfig = core_1.ClientConfig;
const lodash_1 = tslib_1.__importDefault(require("lodash"));
/**
 * Instantiate a Client object with desired ClientConfig to perform operations
 * available in this API client.
 *
 * Note: When performing operations that require ShopperJWT authentication, an
 * Authorization header containing a JWT can be added to the headers field of the
 * ClientConfig object. The Client will use that Authorization header for all the
 * operations it is used to perform.
 */
class Client extends core_1.BaseClient {
  constructor(config) {
    super(config);
    if (!!!config.baseUri) {
      this.clientConfig.baseUri =
        "https://{shortCode}.api.commercecloud.salesforce.com/pricing/assignments/{version}";
    }
  }
  /**
    * Searches for promotion campaign assignments.

The promotioncampaignassignment search document contains a search object that allows filtering on various attributes.

The query attribute specifies a complex query that can be used to narrow down the search. attributes are grouped\n into different buckets.  these are the list of searchable attributes with their corresponding buckets:
  
   main:
     
          rank - integer
          startDate - date
          endDate - date
                    
          campaign:
            
            campaignId - string
            
          promotion:
              
            promotionId - string
            description - string
            enabled - boolean
            
          special handling:
            
          couponId - string
          
          
          Only fields in the same bucket can be joined using a disjunction (or). For instance, when joining campaignId and rank above, only a conjunction is allowed (and), whereas promotionId and description can be joined to each other using an &#x27;or&#x27; because they are in the same bucket. Special handling fields must always use\n conjunctions. If the field is used in a  disjunction (or) that violates this rule, and an exception is thrown.
          
          Expands that can be applied for the search request:
          
          promotion
          campaign
         
         Note that only searchable attributes (excluding the ones marked with above with an asterisk) can be used in sorting.
    */
  assignmentsSearch(options) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    queryParameters["siteId"] !== undefined
      ? queryParameters["siteId"]
      : this.clientConfig.parameters["siteId"];
    // @ts-ignore
    return core_1.StaticClient.post({
      client: this,
      rawResponse: (options || {}).rawResponse,
      path: "/organizations/{organizationId}/assignments",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
}
exports.Client = Client;
exports.default = Client;
//# sourceMappingURL=Assignments.js.map
