import { BaseClient, ClientConfig } from "@commerce-apps/core";
import { CouponRedemptionSearchResult, CouponCodes, CouponSearchResult, Coupon } from "./Coupons.types";
export { SiteId, SearchRequest, PaginatedSearchResult, SimpleSearchResult, ErrorResponse, Offset, Limit, CouponRedemptionSearchResult, CouponCodes, RedemptionLimits, CouponRedemption, RedemptionLimitPerPeriod, CouponCode, CouponSearchResult, Coupon, CouponMultiCodesRequest, CouponSystemCodeConfig, } from "./Coupons.types";
/**
* Instantiate a Client object with desired ClientConfig to perform operations
* available in this API client.
*
* Note: When performing operations that require ShopperJWT authentication, an
* Authorization header containing a JWT can be added to the headers field of the
* ClientConfig object. The Client will use that Authorization header for all the
* operations it is used to perform.
*/
export declare class Client extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Searches for coupons.

 The Coupon Search document contains a search object that allows filtering on various attributes.

 The query attribute specifies a complex query that can be used to narrow down the search. These are the list
 of searchable attributes:
 
 coupon_id - String
 description - String
 type - one of {&quot;single_code&quot;, &quot;multiple_codes&quot;, &quot;system_codes&quot;}
 enabled - boolean
 

 Note that only searchable attributes can be used in sorting.

 The stats expand value is required to return the following fields in the Coupon document:
 
     exported_code_count
     redemption_count
     total_codes_count
 
    */
    couponsSearch(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CouponSearchResult>;
    /**
    * Searches for coupon redemptions.

The Coupon Redemption Search document contains a search object that allows filtering on various attributes.


The query attribute specifies a complex query that can be used to narrow down the search. These are the list
of searchable attributes:

    code - String
    coupon_id - String
    customer_email - String
    order_no - String


Note that only searchable attributes can be used in sorting.

If the role to which the user belongs does not have View_Coupon_Codes permission, then the coupon codes returned will be masked.
    */
    couponRedemptionsSearch(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CouponRedemptionSearchResult>;
    /**
    * Delete a coupon by ID.
    */
    deleteCoupon(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            couponId: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Returns coupon information for the given coupon ID.

 The following fields are returned in the Coupon document when specifying the stats expand:

     exported_code_count
     redemption_count
     total_codes_count



 If the role to which the user belongs does not have the View_Coupon_Codes permission, then the coupon codes returned are masked.
    */
    getCoupon(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            couponId: any;
            select?: any;
            expand?: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Coupon>;
    /**
    * Updates the coupon with the specified information.
    */
    updateCoupon(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            couponId: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Coupon>;
    /**
    * Creates a coupon using the information provided. If a coupon exists with the same unique identifier,
 the coupon is replaced completely.
    */
    createCoupon(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            couponId: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Coupon>;
    /**
    * Get the coupon codes for the given coupon.

 If the user role does not have the View_Coupon_Codes permission, then the coupon codes returned are masked.
    */
    getCouponCodes(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            couponId: any;
            offset?: any;
            limit?: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | CouponCodes>;
    /**
    * Add or delete (modify) multiple codes to and from the supplied coupon.
    */
    updateCouponCodes(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            couponId: any;
            delete?: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=Coupons.d.ts.map