import { BaseClient, ClientConfig } from "@commerce-apps/core";
import { GiftCertificate, GiftCertificateSearchResult } from "./GiftCertificates.types";
export { ErrorResponse, Offset, Limit, SiteId, SearchRequest, PaginatedSearchResult, SimpleSearchResult, Money, GiftCertificate, GiftCertificateSearchResult, AccountTransaction, GiftCertificates, } from "./GiftCertificates.types";
/**
* Instantiate a Client object with desired ClientConfig to perform operations
* available in this API client.
*
* Note: When performing operations that require ShopperJWT authentication, an
* Authorization header containing a JWT can be added to the headers field of the
* ClientConfig object. The Client will use that Authorization header for all the
* operations it is used to perform.
*/
export declare class Client extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Creates a gift certificate using the information provided. If a gift certificate with
 the same unique identifier is generated, it is deleted and a new one is created.
    */
    createGiftCertificate(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | GiftCertificate>;
    /**
    * Searches for gift certificates. The query attribute specifies a complex query that can be used to narrow down the search. These are the list of searchable attributes:
 
 merchant_id - String
 masked_gift_certificate_code* - String
 order_no - String
 sender_name - String
 recipient_name - String
 recipient_email - String
 status - String
 enabled - Boolean
 message - String
 description - String
 creation_date - Date
 currency_mnemonic* - String
 
 * masked_gift_certificate_code, also known as just code, can only be used in a term query.  If a
 four-character code is supplied, it is assumed that the search is on the unmasked portion of the code, otherwise
 the full code must be matched.  Text queries are not allowed.
 * currency_mnemonic can only be joined with other attributes using a conjunction (AND).

 Note that only searchable attributes can be used in sorting.  The code attribute cannot be used for sorting.
    */
    giftCertificatesSearch(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | GiftCertificateSearchResult>;
    /**
    * Deletes the gift certificate by merchant ID.
    */
    deleteGiftCertificate(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            merchantId: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | GiftCertificate>;
    /**
    * Action to get gift certificate information using merchant ID.
    */
    getGiftCertificate(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            merchantId: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | GiftCertificate>;
    /**
    * Updates the gift certificate with the specified information using merchant ID.
    */
    updateGiftCertificate(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            merchantId: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | GiftCertificate>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=GiftCertificates.d.ts.map