import { BaseClient, ClientConfig } from "@commerce-apps/core";
import { PromotionSearchResult, Promotion } from "./Promotions.types";
export { ErrorResponse, Offset, Limit, SiteId, SearchRequest, PaginatedSearchResult, SimpleSearchResult, PromotionSearchResult, TimeOfDay, Campaign, PromotionCampaignAssignment, Tag, Promotion, PromotionAssignmentInformation, Schedule, Recurrence, PromotionAbtestGroupAssignment, } from "./Promotions.types";
/**
* Instantiate a Client object with desired ClientConfig to perform operations
* available in this API client.
*
* Note: When performing operations that require ShopperJWT authentication, an
* Authorization header containing a JWT can be added to the headers field of the
* ClientConfig object. The Client will use that Authorization header for all the
* operations it is used to perform.
*/
export declare class Client extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Searches for promotions.
 
 The SearchRequest document contains a search object that allows filtering on various attributes.
 
 The query attribute specifies a complex query that can be used to narrow down the search. These are the searchable
 attributes:
 
 id - String
 name - String
 currency_code - String
 exclusivity - String
 enabled - Boolean
 
 Note that only searchable attributes can be used in sorting. Additionally, the following attribute can be used to
 sort:
 
 promotion_class - String
 
    */
    promotionsSearch(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | PromotionSearchResult>;
    /**
    * Deletes the promotion by ID.
    */
    deletePromotion(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            id: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Action to get promotion information.
    */
    getPromotion(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            id: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Promotion>;
    /**
    * Updates the promotion with the specified information.
    */
    updatePromotion(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            id: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Promotion>;
    /**
    * Creates a promotion using the information provided.
    */
    createPromotion(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            id: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Promotion>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=Promotions.d.ts.map