/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@commerce-apps/core");
exports.ClientConfig = core_1.ClientConfig;
const lodash_1 = tslib_1.__importDefault(require("lodash"));
/**
 * Instantiate a Client object with desired ClientConfig to perform operations
 * available in this API client.
 *
 * Note: When performing operations that require ShopperJWT authentication, an
 * Authorization header containing a JWT can be added to the headers field of the
 * ClientConfig object. The Client will use that Authorization header for all the
 * operations it is used to perform.
 */
class Client extends core_1.BaseClient {
  constructor(config) {
    super(config);
    if (!!!config.baseUri) {
      this.clientConfig.baseUri =
        "https://{shortCode}.api.commercecloud.salesforce.com/pricing/shopper-gift-certificates/{version}";
    }
  }
  /**
   * Action to retrieve an existing gift certificate.
   */
  getGiftCertificate(options) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    queryParameters["siteId"] !== undefined
      ? queryParameters["siteId"]
      : this.clientConfig.parameters["siteId"];
    // @ts-ignore
    return core_1.StaticClient.post({
      client: this,
      rawResponse: (options || {}).rawResponse,
      path: "/organizations/{organizationId}/gift-certificate",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
}
exports.Client = Client;
exports.default = Client;
//# sourceMappingURL=ShopperGiftCertificates.js.map
