import { BaseClient, ClientConfig } from "@commerce-apps/core";
import { PromotionResult } from "./ShopperPromotions.types";
export { ErrorResponse, Offset, Limit, Error, SiteId, SearchRequest, PaginatedSearchResult, SimpleSearchResult, Promotion, PromotionResult, } from "./ShopperPromotions.types";
/**
* Instantiate a Client object with desired ClientConfig to perform operations
* available in this API client.
*
* Note: When performing operations that require ShopperJWT authentication, an
* Authorization header containing a JWT can be added to the headers field of the
* ClientConfig object. The Client will use that Authorization header for all the
* operations it is used to perform.
*/
export declare class Client extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Returns an array of enabled promotions for a list of specified IDs. In the request URL, you can specify up to 50 IDs. If you specify an ID that contains either parentheses or the separator characters, you must URL encode these characters. Each request returns only enabled promotions as the server does not consider promotion qualifiers or schedules.
    */
    getPromotions(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            siteId?: any;
            ids: any;
            locale?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | PromotionResult>;
    /**
    * Handles get promotion by filter criteria. Returns an array of enabled promotions matching the specified filter
criteria. In the request URL, you must provide a campaign_id parameter, and you can optionally specify a date
range by providing start_date and end_date parameters. Both parameters are required to specify a date range, as
omitting one causes the server to return a MissingParameterException fault. Each request returns only enabled
promotions, since the server does not consider promotion qualifiers or schedules.
    */
    getPromotionsForCampaign(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            campaignId: any;
            siteId?: any;
            startDate?: any;
            endDate?: any;
            currency?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | PromotionResult>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=ShopperPromotions.d.ts.map