import { BaseClient, ClientConfig } from "@commerce-apps/core";
import { CategoryProductAssignmentSearchResult, CategorySearchResult, Category, Categories, Catalogs, CatalogSearchResult, CategoryProductAssignment, Catalog } from "./Catalogs.types";
export { BoolFilter, MatchAllQuery, FilteredQuery, ResultPage, SimpleSearchResult, QueryFilter, Query, TermQuery, SearchRequest, TermFilter, TextQuery, Total, Range2Filter, BoolQuery, PaginatedSearchResult, NestedQuery, Filter, Sort, RangeFilter, SiteId, Error, Money, CategoryProductAssignmentSearchResult, ProductOption, Master, CategorySearchResult, Category, VariationAttribute, CatalogCategoryId, Categories, SortingRule, ProductType, Variant, VariationGroup, ProductOptionValue, VariationAttributes, CategoryLinks, MarkupText, ImageGroup, Catalogs, CategoryLink, MediaFile, VariationAttributeValues, CatalogSearchResult, Site, ProductOptions, Product, CategoryProductAssignment, VariationAttributeValue, ProductOptionValues, CustomerListLink, PathRecord, Catalog, SortingRuleStep, } from "./Catalogs.types";
/**
* Instantiate a Client object with desired ClientConfig to perform operations
* available in this API client.
*
* Note: When performing operations that require ShopperJWT authentication, an
* Authorization header containing a JWT can be added to the headers field of the
* ClientConfig object. The Client will use that Authorization header for all the
* operations it is used to perform.
*/
export declare class Client extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Action to get the list of catalog IDs with no filtering.
    */
    getCatalogs(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            select?: any;
            expand?: any;
            offset?: any;
            limit: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Catalogs>;
    /**
    * Gets the catalog with the specified information.
    */
    getCatalog(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            catalogId: any;
            select?: any;
            expand?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Catalog>;
    /**
    * Updates the catalog with the specified information.
    */
    updateCatalog(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            catalogId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Catalog>;
    /**
    * Action to get all the categories with no filtering.
    */
    getCategoriesFromCatalog(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            catalogId: any;
            select?: any;
            expand?: any;
            offset?: any;
            limit: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Categories>;
    /**
    * Deletes the category by catalog ID and category ID.
    */
    deleteCategoryFromCatalog(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            catalogId: any;
            categoryId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Action to read an existing category within a catalog. By default, the server
also returns the first level of sub-categories, but you can specify another level by setting the levels
parameter. Using a large value for levels may cause performance
issues in case of a large and deep category tree.
    */
    getCategoryFromCatalog(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            catalogId: any;
            categoryId: any;
            levels?: any;
            expand?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Category>;
    /**
    * Updates a catalog category using the information provided.
    */
    updateCategoryInCatalog(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            catalogId: any;
            categoryId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Category>;
    /**
    * Creates a catalog category using the information provided.
    */
    createCategoryInCatalog(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            catalogId: any;
            categoryId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Category>;
    /**
    * Searches for category product assignments.
 
 The query attribute specifies a complex query that can be used to narrow down the search. This is the list
 of searchable attributes:
 
 product_id - String
 product_name - String
 online_flag - Boolean
 searchable - Boolean
 valid_from - DateTime
 valid_to - DateTime
 creation_date - DateTime
 
 
 Sortable Fields:
 
 product_id - String
 product_name - String
 position - Double
 creation_date - DateTime
 
 
 Expansions that can be applied for the search request:
 
 product_base - String - This expand will enable retrieval of the following basic Product information:
 product_images - String - to fetch preview image and image groups specified for the given product
 product_all_images - String - to fetch preview image and image groups specified for the product plus images for its variants and variation groups
 product_variations - String to fetch variations related information, version 17.8+
 product_availability - String to fetch availability related information, version 17.8+
 product_categories - String to fetch category related information, version 17.8+
 product_prices - String to fetch prices related information, version 17.8+
 product_options - String to fetch options related information, version 17.8+
 product_all - String to fetch all expanded information, version 17.8+

    
        brand
        ean
      link
    long_description
      manufacturer_name
      manufacturer_sku
        name
      page_description
      page_keywords
      page_title
      searchable
    short_description
      type
      unit
        upc
    
 
    */
    searchProductsAssignedToCategory(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            catalogId: any;
            categoryId: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CategoryProductAssignmentSearchResult>;
    /**
    * Retrieves a category product assignment.


For example, if we have products A, B, C at positions 1, 2, 7.5, and delete assignment for product B,
  the products end up A, B, C at positions 1, null, 7.5.
    */
    getAssignedProductFromCategory(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            catalogId: any;
            categoryId: any;
            productId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | CategoryProductAssignment>;
    /**
    * Removes a category product assignment.


For example, if we have products A, B, C at positions 1, 2, 7.5 and delete assignment for product B,
the products end up A, B, C at positions 1, null, 7.5.
    */
    unassignProductFromCategory(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            catalogId: any;
            categoryId: any;
            productId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Updates the category product assignment with the specified information, such as position.
  As the assigned position n is a normalized target position, we&#x27;ll make sure that the product is assigned
to a position so that the order of positions are maintained.

For example, if we have products A, B, C, D at positions 1, 2, 3, 4 and update product A with a  new position of 3,
the end result is B, C, A, D with order of positions 1, 2, 3, 4. If we then update product C to no position,
the end result is B, A, D, C with order of positions 1, 2, 3, null.

If there are n existing positioned assignments, updating product to position &gt;&#x3D; n will end with a new assignment with a position such that the order of positions is maintained.
    */
    updateProductCategoryAssignment(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            catalogId: any;
            categoryId: any;
            productId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CategoryProductAssignment>;
    /**
    * Creates a category product assignment using the information provided.

As the assigned position n is a normalized target position, we&#x27;ll make sure that the product is assigned
to a position so that the order of positions are maintained.

For example, if we have products A, B, C at positions 1, 2, 3, and product D is assigned to
position 2, the end result is A, D, B, C with order of positions 1, 2, 3, 4.

If there are n existing positioned assignment, assigning a new product to position &gt;&#x3D; n+1 will end
with the new assignment with position n+1.
    */
    assignProductToCategory(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            catalogId: any;
            categoryId: any;
            productId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CategoryProductAssignment>;
    /**
    * Searches for catalog categories in the scope of catalog.
By default, the server also returns the first level of subcategories,
  but you can specify another level by setting the levels parameter.
  Using a large value for levels may cause performance
  issues with a large and deep category tree.

The query attribute specifies a complex query that can be used to narrow down the search. These are the list searchable attributes:

id - String
name - String
description - String
creation_date - DateTime
online - Boolean
parent_category_id - String


The output of the query can also be sorted. These are the the sortable attributes:

id - String
name - String
description - String
creation_date - DateTime
online - Boolean
position - Double
    */
    searchCategoriesInCatalog(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            catalogId: any;
            levels?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CategorySearchResult>;
    /**
    * Searches for catalogs.

The query attribute specifies a complex query that can be used to narrow down the search. These are the  searchable attributes:

id - String
name - String
description - String
creation_date - DateTime


There are two additional fields that can be used as search filters. They are not attributes in CatalogWO object,
but can be used as filters to query catalogs based on site assignments.

is_master_catalog - Boolean
is_storefront_catalog - Boolean


On using is_master_catalog in the search query, catalogs without any site assignments are returned.
On using is_storefront_catalog in the search query, catalogs with one or more site assignments are returned.

The output of the query can also be sorted. These are the sortable attributes:

id - String
name - String
description - String
creation_date - DateTime
    */
    searchCatalogs(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CatalogSearchResult>;
    /**
    * Searches for catalog categories anywhere they appear.
By default, the server also returns the first level of subcategories,
  but you can specify another level by setting the levels parameter.
  Please note, using a large value for levels may cause performance
  issues with a large and deep category tree.

The query attribute specifies a complex query that can be used to narrow down the search. These are the searchable attributes:

id - String
name - String
description - String
creation_date - DateTime
online - Boolean
catalog_id - String


The output of the query can also be sorted. These are the sortable attributes:

id - String
name - String
description - String
creation_date - DateTime
online - Boolean
position - Double
    */
    searchCategories(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            levels?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CategorySearchResult>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=Catalogs.d.ts.map