import { BaseClient, ClientConfig } from "@commerce-apps/core";
import { ProductSearchResult, SuggestionResult } from "./ShopperSearch.types";
export { ErrorResponse, Offset, Limit, ProductRef, SuggestedTerms, CategorySuggestions, SuggestedProduct, SuggestedPhrase, VariationAttribute, ProductSuggestions, SuggestedCategory, ProductType, BrandSuggestions, ProductSearchRefinementValue, ProductSearchSortingOption, SuggestedTerm, ProductSearchRefinement, CustomSuggestions, ProductSearchHit, ProductSearchResult, Image, VariationAttributeValue, Suggestion, SuggestionResult, SiteId, SearchRequest, PaginatedSearchResult, SimpleSearchResult, } from "./ShopperSearch.types";
/**
* Instantiate a Client object with desired ClientConfig to perform operations
* available in this API client.
*
* Note: When performing operations that require ShopperJWT authentication, an
* Authorization header containing a JWT can be added to the headers field of the
* ClientConfig object. The Client will use that Authorization header for all the
* operations it is used to perform.
*/
export declare class Client extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Provides keyword and refinement search functionality for products. Only returns the product ID, link, and name in
the product search hit. The search result contains only products that are online and assigned to site catalog.
    */
    productSearch(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            siteId?: any;
            q?: any;
            refine?: any;
            sort?: any;
            offset?: any;
            limit?: any;
            currency?: any;
            locale?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | ProductSearchResult>;
    /**
    * Provides keyword search functionality for products, categories, and brands suggestions. Returns suggested products, suggested categories, and suggested brands for the given search phrase.
    */
    getSearchSuggestions(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            siteId?: any;
            q: any;
            limit?: any;
            currency?: any;
            locale?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | SuggestionResult>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=ShopperSearch.d.ts.map