import { BaseClient, ClientConfig } from "@commerce-apps/core";
import { StoreResult, Store } from "./ShopperStores.types";
export { ErrorResponse, Offset, Limit, SiteId, SearchRequest, PaginatedSearchResult, SimpleSearchResult, CountryCode, Latitude, Longitude, StoreResult, DistanceUnit, Distance, PostalCode, Store, } from "./ShopperStores.types";
/**
* Instantiate a Client object with desired ClientConfig to perform operations
* available in this API client.
*
* Note: When performing operations that require ShopperJWT authentication, an
* Authorization header containing a JWT can be added to the headers field of the
* ClientConfig object. The Client will use that Authorization header for all the
* operations it is used to perform.
*/
export declare class Client extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * This resource retrieves a list of stores for the given site that are within a configured distance of a geolocation. The distance is interpreted either in miles or kilometers, depending on the distanceUnit input parameter. The location is specified either by directly providing a latitude and longitude coordinate pair, or by providing a country and a postal code. If a postal code is passed, the resource looks in the system&#x27;s geolocation mappings to find the coordinates for this postal code. If no matching geolocation is found, the resource returns an empty list of stores. If coordinates are passed, the values for country and postal code are ignored.
    */
    getStores(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            siteId?: any;
            latitude?: any;
            longitude?: any;
            countryCode?: any;
            postalCode?: any;
            distanceUnit?: any;
            maxDistance?: any;
            limit?: any;
            offset?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | StoreResult>;
    /**
    * Returns a store identified by its ID.
    */
    getStore(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            id: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Store>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=ShopperStores.d.ts.map