/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { ShopperToken } from "@commerce-apps/core";
import * as sdk from "./";
declare const shopperAuthApi: (options: {
  rawResponse?: boolean;
  parameters?: {
    organizationId?: any;
    clientId: any;
    siteId?: any;
  };
  headers?: {
    [key: string]: string;
  };
  body: object;
}) => Promise<Response | sdk.Customer.ShopperCustomers.Customer>;
/**
 * @description This wraps the parameters for the authCall to retrieve a token.
 *  That call can be called directly, this is here just for convenience
 * @export
 * @template T A template used to extend the parameters of the shopper authentication call
 * @param {(T extends (arg: infer A) => any
 *           ? { parameters: { clientId?: string; shortCode?: string } } & A
 *           : never)} options This provides the type ahead for this parameter properly
 * @returns {Promise<ShopperToken>}
 */
export declare function getAuthToken<T extends typeof shopperAuthApi>(
  options: T extends (arg: infer A) => any
    ? {
        parameters: {
          clientId?: string;
          shortCode?: string;
        };
      } & A
    : never
): Promise<ShopperToken>;
export {};
//# sourceMappingURL=helpers.d.ts.map
