/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@commerce-apps/core");
const sdk = tslib_1.__importStar(require("./"));
const shopperAuthApi =
  sdk.Customer.ShopperCustomers.Client.prototype.authorizeCustomer;
/**
 * @description This wraps the parameters for the authCall to retrieve a token.
 *  That call can be called directly, this is here just for convenience
 * @export
 * @template T A template used to extend the parameters of the shopper authentication call
 * @param {(T extends (arg: infer A) => any
 *           ? { parameters: { clientId?: string; shortCode?: string } } & A
 *           : never)} options This provides the type ahead for this parameter properly
 * @returns {Promise<ShopperToken>}
 */
function getAuthToken(options) {
  return tslib_1.__awaiter(this, void 0, void 0, function*() {
    const client = new sdk.Customer.ShopperCustomers.Client({
      parameters: {
        shortCode: options.parameters.shortCode
      }
    });
    options.rawResponse = true;
    // At some point this should go through the same stripping as everything else.
    //  Should be part of the global config story
    delete options.parameters.shortCode;
    const response = yield client.authorizeCustomer(options);
    if (!response.ok) {
      throw new Error(`${response.status}: ${response.statusText}`);
    }
    return new core_1.ShopperToken(
      core_1.stripBearer(response.headers.get("Authorization"))
    );
  });
}
exports.getAuthToken = getAuthToken;
//# sourceMappingURL=helpers.js.map
